"use client";

import Image from "next/image";

import { MoveLeft, MoveRight } from "lucide-react";

import { ContentLines } from "@/components/shared/content-lines";
import { Button } from "@/components/ui/button";
import { TextAnimate } from "@/components/ui/text-animate";
import { ImageBaseUrl } from "@/configs/api";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { useLocale, useTranslations } from "next-intl";

export default function Hero() {
	const locale = useLocale() as Locale;
	const t = useTranslations("HomePage");
	// const heroData = await getFakeData();
	const isRTL = locale === "ar";

	const { texts } = useBasicInfo();

	return (
		<div className="grid grid-cols-4 grid-rows-[60vh_auto_40vh] lg:grid-cols-12 lg:grid-rows-[75vh_25vh]"
			style={{ direction: isRTL ? "ltr" : "rtl" }}>
			{/* Sidebar */}
			<div
				className={"col-span-4 row-span-3 bg-[#00629F] text-white lg:col-span-3 lg:row-span-2"}>
				<div
					className={"flex h-full flex-col items-center p-4 text-center md:p-6 md:px-10"}
				>
					<ContentLines
						title={texts?.sidebar_section_main_title?.[locale]}
						className={"mb-5 self-end"}
						titleSize="text-[15px]"
					/>
					<div className="mb-12 flex h-[120px] w-[120px] items-center justify-center rounded-full bg-white md:mb-14">
						<Image
							src={ImageBaseUrl + texts?.sidebar_section_img}
							alt="Bin Taleb Logo"
							width={100}
							height={100}
							className="rounded-full"
						/>
					</div>
					<TextAnimate
						animation="fadeIn"
						as="h2"
						className="mb-2 text-xl font-bold md:mb-4 md:text-2xl"
						style={{ direction: isRTL ? "rtl" : "ltr" }}
					>
						{texts?.sidebar_section_subtitle?.[locale]}
					</TextAnimate>
					<TextAnimate
						animation="slideUp"
						by="word"
						as="h4"
						className="mb-4 text-lg md:text-[16px]"
						style={{ direction: isRTL ? "rtl" : "ltr" }}
					>
						{texts?.sidebar_section_text?.[locale]}
					</TextAnimate>
					<div className="mt-auto flex w-full flex-col items-center">
						<Button
							variant="outline"
							className="text-md mb-2 rounded-2xl border-4 border-white bg-[#00629F] px-8 py-5"
						>
							<TextAnimate animation="scaleUp">{t("details")}</TextAnimate>
						</Button>
						{isRTL ? (
							<MoveLeft
								className="animate-bounce self-end"
								size={60}
								color="#ffffff"
							/>
						) : (
							<MoveRight
								className="animate-bounce self-start"
								size={60}
								color="#ffffff"
							/>
						)}
					</div>
				</div>
			</div>

			{/* Main Hero Section */}
			<div
				className={"relative col-span-4 row-start-1 lg:col-span-9"}
			>
				<Image
					src={ImageBaseUrl + texts?.banner_background_img}
					alt="Swimming pool with loungers"
					fill
					className="object-cover"
					priority
				/>
				<div className="absolute inset-0 bg-black/40" />
				<div
					className={cn(
						"absolute inset-0 flex flex-col justify-center p-4 text-white md:p-8 md:px-12",
						isRTL ? "items-start" : "items-end"
					)}
				>
					<div className="mb-2 md:mb-4">
						<TextAnimate
							animation="blurInUp"
							by="word"
							as="h1"
							className="mb-4 self-end text-xl font-bold md:text-3xl lg:text-4xl"
							style={{ direction: isRTL ? "rtl" : "ltr" }}
						>
							{texts?.banner_title?.[locale]}
						</TextAnimate>
						<TextAnimate
							animation="blurInUp"
							by="text"
							as="h2"
							className="self-end text-xl font-bold md:text-3xl lg:text-4xl"
						>
							{texts?.banner_title?.[isRTL ? "en" : "ar"]}
						</TextAnimate>
					</div>
				</div>
			</div>

			{/* Bottom Section */}
			<div
				className={"col-span-4 row-start-3 lg:col-span-9 lg:row-start-2"}
				style={{ direction: isRTL ? "rtl" : "ltr" }}
			>
				<div
					className={"flex h-full flex-col gap-4 md:gap-6 md:flex-row"}
				>

					<div style={{ display: "flex", alignItems: "center" }}>
						<TextAnimate
							animation="fadeIn"
							by="line"
							as="p"
							className={`px-4 text-center text-sm text-gray-600 md:px-6 md:text-base lg:text-lg ${isRTL ? "md:text-right" : "md:text-left"
								}`}
						>
							{texts?.banner_text?.[locale]}
						</TextAnimate>
					</div>

					<Image
						src={ImageBaseUrl + texts?.banner_side_img}
						width={335}
						height={250}
						alt="Company Flag"
						className="object-contain"
					/>

				</div>
			</div>
		</div>
	);
}
